package MyUtil;

use base qw/Util::Any/;
our $Utils =
  {
   list => [['List::Util' => 'lu_']],
  };

1;
